#! /usr/bin/python
# -*- coding: iso-8859-1 -*-
#
__author__='lorenzo.carbonell.cerezo@gmail.com'
__date__ ='$21/02/2012'
#
# Catch-Indicator
# An indicator for Catch.com
#
# Copyright (C) 2012 Lorenzo Carbonell
# lorenzo.carbonell.cerezo@gmail.com
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
#
import os
import gi
gi.require_version('Gtk', '3.0')
from gi.repository import GObject
from gi.repository import AppIndicator3 as appindicator
from gi.repository import Gtk
from gi.repository import GdkPixbuf
from gi.repository import Notify

import time
import dbus
import locale
import gettext
import datetime
import webbrowser
#
import comun
import catchapi
from configurator import Configuration
from preferences_dialog import Preferences
from add_new_note_dialog import AddNewNoteDialog
from show_notes_dialog import ShowNotesDialog
#

locale.setlocale(locale.LC_ALL, '')
gettext.bindtextdomain(comun.APP, comun.LANGDIR)
gettext.textdomain(comun.APP)
_ = gettext.gettext

def internet_on():
	try:
		response=urllib2.urlopen('http://google.com',timeout=1)
		return True
	except:
		pass
	return False

def add2menu(menu, text = None, icon = None, conector_event = None, conector_action = None):
	if text != None:
		if icon == None:
			menu_item = Gtk.MenuItem.new_with_label(text)
		else:
			menu_item = Gtk.ImageMenuItem.new_with_label(text)
			image = Gtk.Image.new_from_stock(icon, Gtk.IconSize.MENU)
			menu_item.set_image(image)
			menu_item.set_always_show_image(True)
	else:
		if icon == None:
			menu_item = Gtk.SeparatorMenuItem()
		else:
			menu_item = Gtk.ImageMenuItem.new_from_stock(icon, None)
			menu_item.set_always_show_image(True)
	if conector_event != None and conector_action != None:				
		menu_item.connect(conector_event,conector_action)
	menu_item.show()
	menu.append(menu_item)
	return menu_item

class CatchIndicator():
	def __init__(self):
		if dbus.SessionBus().request_name("es.atareao.catch-indicator") != dbus.bus.REQUEST_NAME_REPLY_PRIMARY_OWNER:
			print "application already running"
			exit(0)
		self.indicator = appindicator.Indicator.new('Catch-Indicator', 'Catch-Indicator', appindicator.IndicatorCategory.APPLICATION_STATUS)
		self.read_preferences()
		#
		self.events = []
		self.set_menu()
		self.actualization_time = time.time()
		GObject.timeout_add_seconds(60, self.work)

	def read_preferences(self):
		error = True
		while error:
			try:
				configuration = Configuration()
				self.cs = catchapi.CatchSession()
				self.user = self.cs.login(configuration.get('user'),configuration.get('password'))
				self.time = configuration.get('time')
				self.theme = configuration.get('theme')
				self.ids = {}
				self.ids[0] = configuration.get('id0')
				self.ids[1] = configuration.get('id1')
				self.ids[2] = configuration.get('id2')
				self.ids[3] = configuration.get('id3')
				self.ids[4] = configuration.get('id4')
				self.ids[5] = configuration.get('id5')
				self.ids[6] = configuration.get('id6')
				self.ids[7] = configuration.get('id7')
				self.ids[8] = configuration.get('id8')
				self.ids[9] = configuration.get('id9')
				error = False
			except catchapi.AuthorizationError,e:
				print e
				error = True
				if configuration.get('user') == '' and configuration.get('password') == '********':
					message = _('Configure Catch-Indicator')
				else:
					message = _('The username or/and the password are incorrect\nplease, try again?')
				md = Gtk.MessageDialog(
					None,
					Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
					Gtk.MessageType.WARNING,
					Gtk.ButtonsType.OK_CANCEL,
					message)
				if md.run() == Gtk.ResponseType.CANCEL:
					exit(3)
				md.destroy()
				p = Preferences()
				if p.run() == Gtk.ResponseType.ACCEPT:
					p.save_preferences()
				else:
					exit(1)
				p.destroy()
		

	def work(self):
		if (time.time()-self.actualization_time) > self.time*60:
			while internet_on() == False:
				time.sleep(1)
			self.actualization_time = time.time()
			self.set_menu(check=True)
		return True
	
	def accept_new_notes(self):
		if self.indicator.get_status() == appindicator.IndicatorStatus.ATTENTION:
			configuration = Configuration()
			self.renew_ids()
			for id in range(0,10):
				print self.ids[id]
				print 'id: %s -> %s'%(id,self.ids[id])
				configuration.set('id%s'%id,self.ids[id])
			configuration.save()
			self.indicator.set_status(appindicator.IndicatorStatus.ACTIVE)
			
	
	def check_notes(self):
		if self.is_empty():
			self.read_ids()
			return False
			
		for note in self.user.get_notes_sort():
			if not self.exists_id(note['id']):
				return False
		return True

	def is_empty(self):
		for i in range(0,10):
			if len(self.ids[i]) == 0:
				return True
		return False
	def renew_ids(self):
		id = 9
		for note in self.user.get_notes_sort():
			self.ids[id] = note['id']
			id -= 1
		
	def read_ids(self):
		id = 9
		for note in self.user.get_notes_sort():
			self.ids[id] = note['id']
			id -= 1
		
	def exists_id(self,id):
		for i in range(0,10):
			if self.ids[i] == id:
				return True
		return False

	def set_menu(self,check=False):
		#
		now = datetime.datetime.now()		
		normal_icon = os.path.join(comun.ICONDIR,'catch-indicator-%s-normal.svg'%(self.theme))
		starred_icon = os.path.join(comun.ICONDIR,'catch-indicator-%s-starred.svg'%(self.theme))
		#
		self.indicator.set_icon(normal_icon)
		self.indicator.set_attention_icon(starred_icon)		
		#
		self.menu = Gtk.Menu()
		#
		if self.check_notes():
			self.indicator.set_status(appindicator.IndicatorStatus.ACTIVE)
		else:
			self.indicator.set_status(appindicator.IndicatorStatus.ATTENTION)
		add2menu(self.menu)
		add2menu(self.menu, text = _('Add new Note'), conector_event = 'activate',conector_action = self.menu_add_new_note)
		self.menu_show_notes = add2menu(self.menu, text = _('Show Notes'), conector_event = 'activate',conector_action = self.menu_show_notes)
		add2menu(self.menu)
		self.menu_preferences = add2menu(self.menu, text = _('Preferences'), conector_event = 'activate',conector_action = self.menu_preferences_response)
		add2menu(self.menu)
		menu_help = add2menu(self.menu, text =_('Help'))
		menu_help.set_submenu(self.get_help_menu())
		add2menu(self.menu)
		add2menu(self.menu, text = _('Exit'), conector_event = 'activate',conector_action = self.menu_exit_response)
		'''
		#
		now = datetime.datetime.now()
		if self.events[0].when[0].start.find('T') != -1:
			print self.events[0].when[0].start
			if self.events[0].when[0].start.find('.') != -1:
				com = datetime.datetime.strptime(self.events[0].when[0].start.split('.')[0],'%Y-%m-%dT%H:%M:%S')
			else:
				com = datetime.datetime.strptime(self.events[0].when[0].start,'%Y-%m-%dT%H:%M:%S')
			
		else:
			com = datetime.datetime.strptime(self.events[0].when[0].start,'%Y-%m-%d')
		if now.year == com.year and now.month == com.month and now.day == com.day and now.hour == com.hour:
			self.indicator.set_status (appindicator.IndicatorStatus.ATTENTION)
		else:
			print now.hour
			print com.hour
			print self.events[0].when[0].start
			self.indicator.set_status (appindicator.IndicatorStatus.ACTIVE)
		#
		'''
		self.menu.show()
		self.indicator.set_menu(self.menu)
		while Gtk.events_pending():
			Gtk.main_iteration()
		

	def get_help_menu(self):
		help_menu =Gtk.Menu()
		#		
		add2menu(help_menu,text = _('Web...'),conector_event = 'activate',conector_action = lambda x: webbrowser.open('https://launchpad.net/catch-indicator'))
		add2menu(help_menu,text = _('Get help online...'),conector_event = 'activate',conector_action = lambda x: webbrowser.open('https://answers.launchpad.net/catch-indicator'))
		add2menu(help_menu,text = _('Translate this application...'),conector_event = 'activate',conector_action = lambda x: webbrowser.open('https://translations.launchpad.net/catch-indicator'))
		add2menu(help_menu,text = _('Report a bug...'),conector_event = 'activate',conector_action = lambda x: webbrowser.open('https://bugs.launchpad.net/catch-indicator'))
		add2menu(help_menu)
		self.menu_about = add2menu(help_menu,text = _('About'),conector_event = 'activate',conector_action = self.menu_about_response)
		#
		help_menu.show()
		#
		return help_menu

	def menu_preferences_response(self,widget):
		self.menu_preferences.set_sensitive(False)
		p = Preferences()
		if p.run() == Gtk.ResponseType.ACCEPT:
			p.save_preferences()
		p.destroy()
		self.read_preferences()
		self.menu_preferences.set_sensitive(True)
					
	def menu_add_new_note(self,widget):
		widget.set_sensitive(False)
		annd = AddNewNoteDialog()
		if annd.run() == Gtk.ResponseType.ACCEPT:
			text = annd.get_text()
			file = annd.get_file()
			note = self.user.post_note(text)
			if file:
				note.add_media(file)
			self.accept_new_notes()
		annd.destroy()
		widget.set_sensitive(True)
	def menu_show_notes(self,widget):
		widget.set_sensitive(False)
		self.accept_new_notes()
		snd = ShowNotesDialog(self.user)
		snd.run()
		snd.destroy()
		self.accept_new_notes()
		widget.set_sensitive(True)

	def menu_exit_response(self,widget):
		exit(0)

	def menu_about_response(self,widget):
		self.menu_about.set_sensitive(False)
		ad=Gtk.AboutDialog()
		ad.set_name(comun.APPNAME)
		ad.set_version(comun.VERSION)
		ad.set_copyright('Copyrignt (c) 2012\nLorenzo Carbonell')
		ad.set_comments(_('An indicator for Catch.com'))
		ad.set_license(''+
		'This program is free software: you can redistribute it and/or modify it\n'+
		'under the terms of the GNU General Public License as published by the\n'+
		'Free Software Foundation, either version 3 of the License, or (at your option)\n'+
		'any later version.\n\n'+
		'This program is distributed in the hope that it will be useful, but\n'+
		'WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\n'+
		'or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for\n'+
		'more details.\n\n'+
		'You should have received a copy of the GNU General Public License along with\n'+
		'this program.  If not, see <http://www.gnu.org/licenses/>.')
		ad.set_website('http://www.atareao.es')
		ad.set_website_label('http://www.atareao.es')
		ad.set_authors(['Lorenzo Carbonell <lorenzo.carbonell.cerezo@gmail.com>'])
		ad.set_documenters(['Lorenzo Carbonell <lorenzo.carbonell.cerezo@gmail.com>'])
		ad.set_logo(GdkPixbuf.Pixbuf.new_from_file(comun.ICON))
		ad.set_program_name(comun.APPNAME)
		ad.run()
		ad.destroy()
		self.menu_about.set_sensitive(True)

if __name__ == "__main__":
	Notify.init("catch-indicator")
	ci=CatchIndicator()
	Gtk.main()

